Frm class

Constructors

Frm({required String code, required String guid, List<FrmPage>? pages, List<FrmChild>? children, List<FrmField>? fields})

Properties

children ↔ List<FrmChild>?
getter/setter pair
code ↔ String
getter/setter pair
docDate ↔ DateTime?
getter/setter pair
docNo ↔ String?
getter/setter pair
docRefNo ↔ String?
getter/setter pair
fields ↔ List<FrmField>?
getter/setter pair
guid ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isLoaded ↔ bool
getter/setter pair
pages ↔ List<FrmPage>?
getter/setter pair
permission ↔ Permission?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited